package com.cultural.heritage.model.dto.good;

import com.baomidou.mybatisplus.annotation.TableField;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;

@Data
@Schema(description = "商品更新请求体", requiredProperties = {"id", "name", "type", "price", "goodImg", "intro",
        "richText", "label", "inventory", "festivalName", "isShelves"})
public class GoodUpdateRequest implements Serializable {

    /**
     * id
     */
    @Schema(description = "商品id(id > 0)", example = "17")
    private Long id;

    /**
     * 商品名
     */
    @Schema(description = "商品名", example = "非遗香囊")
    private String name;

    /**
     * 商品类型
     */
    @Schema(description = "商品类型", example = "材料包")
    private String type;

    /**
     * 商品价格
     */
    @Schema(description = "商品价格", example = "20.00")
    private BigDecimal price;

    /**
     * 商品图片
     */
    @Schema(description = "商品图片", example = "https://xxx/xxx.jpg")
    private String goodImg;

    /**
     * 商品简介
     */
    @Schema(description = "商品简介", example = "传承千年文化，守护健康美好")
    private String intro;

    /**
     * 商品详情（富文本）
     */
    @Schema(description = "商品详情（富文本）", example = "<p></p>")
    private String richText;

    /**
     * 商品标签
     */
    @Schema(description = "商品标签", example = "亲情;送礼;材料包")
    private String label;

    /**
     * 商品库存量
     */
    @Schema(description = "商品库存量", example = "10")
    private Integer inventory;

    /**
     * 限定节日名称
     */
    @Schema(description = "节日名称(端午节，中秋节)", example = "元旦节")
    private String festivalName;


    /**
     * 是否上架
     */
    @Schema(description = "是否上架(1:上架;0:下架)", example = "1")
    private Integer isShelves;


    @Serial
    @TableField(exist = false)
    private static final long serialVersionUID = 1L;
}
